---
title: <span class="badge object-type-scalar"></span> KiloWattMinute
---
# <span class="badge object-type-scalar"></span> KiloWattMinute

Energy: Kilowatt-min (kWm)

## Definition

```python
# Energy: Kilowatt-min (kWm)
KiloWattMinute: typing.Literal["kwattm"] = "kwattm"
```
